@@ -1,6 +1,8 @@
-# $Id: Request.pm 42140 2014-09-03 12:19:40Z wsl $
+# $Id: Request.pm 47634 2018-06-26 13:03:40Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/lib/UvT/Kiki/WS/Alias/Request.pm $
 
+use re '/aa';
+
 package UvT::Kiki::WS::Alias::Request;
 
 use UvT::Kiki::WS::Request -self;
@@ -9,7 +11,7 @@ field address => sub {
 	my $self = shift;
 	my (undef, $address) = @{$self->pairs};
 	die "Malformed value '$address' for field 'address'\n"
-		if defined $address && $address !~ /^[^@]+\@[^@]+$/;
+		if defined $address && $address !~ /^[^@]+\@[^@]+\z/;
 	return $address;
 };
 
